@@ -1,6 +1,5 @@
 import logging
 
-from django.core.exceptions import ObjectDoesNotExist
 from django.core.management.base import BaseCommand
 
 from openlxp_notifications.management.utils.notification import (
@@ -14,10 +13,11 @@ logger = logging.getLogger('dict_config_logger')
 
 def get_sender_email():
     """Getting sender email id"""
-    try:
-        sender_email_configuration = SenderEmailConfiguration.objects.first()
+
+    sender_email_configuration = SenderEmailConfiguration.objects.first()
+    if sender_email_configuration:
         sender = sender_email_configuration.sender_email_address
-    except ObjectDoesNotExist:
+    else:
         sender = None
     return sender
 
@@ -32,7 +32,7 @@ def send_log_email():
     # Getting sender email id
     sender = get_sender_email()
 
-    if sender:
+    if sender and email:
         email_configuration = EmailConfiguration.objects.filter(
             Content_Type='ATTACHMENT').values('HTML_File', 'Subject',
                                               'Email_Content', 'Signature',
@@ -40,10 +40,14 @@ def send_log_email():
                                               'Unsubscribe_Email_ID',
                                               'Content_Type'
                                               ).first()
-
-        send_notifications(email, sender, email_configuration)
+        if email_configuration:
+            send_notifications(email, sender, email_configuration)
+        else:
+            logger.error("Email configuration for email format not set. "
+                         "Email failed to send")
     else:
-        logger.error("Sender email does not exist. Email failed to send")
+        logger.error("Sender/Receiver email does not exist. "
+                     "Email failed to send")
 
 
 def send_log_email_with_msg(email, msg):
@@ -59,8 +63,12 @@ def send_log_email_with_msg(email, msg):
                                            'Unsubscribe_Email_ID',
                                            'Content_Type'
                                            ).first()
-
-        send_notifications_with_msg(email, sender, msg, email_configuration)
+        if email_configuration:
+            send_notifications_with_msg(email, sender,
+                                        msg, email_configuration)
+        else:
+            logger.error("Email configuration for email format not set. "
+                         "Email failed to send")
     else:
         logger.error("Sender email does not exist. Email failed to send")
 
